@@ -1,4 +1,7 @@
+import gzip
 import os
+from io import BytesIO
+
 from cameo_claw.cameo_claw_reuse import bytesio_to_gzip, requests_get_write, \
     bytesio_filename, write_gzip, read_csv_distinct
 from cameo_claw.functional import it_mp_f
@@ -70,7 +73,33 @@ def a_filter(url, target_directory, lst_distinct_column, lst_column_match=[], so
     return requests_get_write(target_directory, url, write)
 
 
-def it_filter(lst_url, target_directory, lst_distinct_column, dic_column_match, sort_column):
+def it_filter(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
     return it_mp_f(a_filter,
                    [tuple([url, target_directory, lst_distinct_column,
-                           dic_column_match, sort_column]) for url in lst_url])
+                           lst_column_match, sort_column]) for url in lst_url])
+
+
+def a_chunk(url, target_directory, lst_distinct_column, lst_column_match=[], sort_column=''):
+    def write(bytes1):
+        df = read_csv_distinct(bytes1, lst_distinct_column)
+        condition = ''
+        for lst_col_val in lst_column_match:
+            condition += f"""(pl.col('{lst_col_val[0]}')=='{lst_col_val[1]}') | """
+        condition = condition[:-3]
+        df = df.filter(eval(condition))
+        if sort_column:
+            df = df.sort(sort_column)
+        bytesio_csv = BytesIO()
+        df.to_csv(bytesio_csv, has_header=False)
+        bytesio_gz = BytesIO()
+        with gzip.open(bytesio_gz, 'wb') as f:
+            f.write(bytesio_csv.getvalue())
+        return bytesio_gz.getvalue()
+
+    return requests_get_write(target_directory, url, write)
+
+
+def it_chunk(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
+    return it_mp_f(a_chunk,
+                   [tuple([url, target_directory, lst_distinct_column,
+                           lst_column_match, sort_column]) for url in lst_url])
