@@ -18,10 +18,9 @@ def bytesio_to_gzip(df, url, target_directory):
 
 def requests_get_write(target_directory, url, f_write):
     try:
-        requests_get(f_write, url, target_directory)
+        return requests_get(f_write, url, target_directory)
     except Exception as e:
         print(f'cameo_claw.py,requests_get_write,Exception:{e, url}')
-    return url
 
 
 def bytesio_filename(df, url):
