@@ -7,12 +7,12 @@ def istarmap37(self, func, iterable, chunksize=1):
     """
     if self._state != mpp.RUN:
         raise ValueError("Pool not running")
-    if chunksize < 1:
-        raise ValueError(
-            "Chunksize must be 1+, not {0:n}".format(
-                chunksize))
-    task_batches = mpp.Pool._get_tasks(func, iterable, chunksize)
+    task_batches = get_tasks(chunksize, func, iterable)
     result = mpp.IMapIterator(self._cache)
+    return taskqueue_put(result, self, task_batches)
+
+
+def taskqueue_put(result, self, task_batches):
     self._taskqueue.put(
         (
             self._guarded_task_generation(result._job,
@@ -23,25 +23,22 @@ def istarmap37(self, func, iterable, chunksize=1):
     return (item for chunk in result for item in chunk)
 
 
+def get_tasks(chunksize, func, iterable):
+    if chunksize < 1:
+        raise ValueError(
+            "Chunksize must be 1+, not {0:n}".format(
+                chunksize))
+    task_batches = mpp.Pool._get_tasks(func, iterable, chunksize)
+    return task_batches
+
+
 def istarmap38(self, func, iterable, chunksize=1):
     """starmap-version of imap
     """
     self._check_running()
-    if chunksize < 1:
-        raise ValueError(
-            "Chunksize must be 1+, not {0:n}".format(
-                chunksize))
-
-    task_batches = mpp.Pool._get_tasks(func, iterable, chunksize)
+    task_batches = get_tasks(chunksize, func, iterable)
     result = mpp.IMapIterator(self)
-    self._taskqueue.put(
-        (
-            self._guarded_task_generation(result._job,
-                                          mpp.starmapstar,
-                                          task_batches),
-            result._set_length
-        ))
-    return (item for chunk in result for item in chunk)
+    return taskqueue_put(result, self, task_batches)
 
 
 if sys.version_info.major == 3 and sys.version_info.minor >= 8:
